@@ -103,6 +103,26 @@ def humanize_time(secs):
 # Some function wrappers that come in handy once in a while
 #
 
+# we use the resource module to get the memory page size
+
+try:
+    import resource
+except ImportError:
+    pass
+
+def get_memory_usage():
+    """
+    Returning resident size in megabytes
+    """
+    pagesize = resource.getpagesize()
+    pid = os.getpid()
+    status_file = "/proc/%s/statm" % (pid)
+    if not os.path.isfile(status_file):
+        return 0.0
+    line = open(status_file).read()
+    size, resident, share, text, library, data, dt = [int(i) for i in line.split()]
+    return resident * pagesize / (1024 * 1024) # return in megs
+
 def time_execution(func):
     """
     Decorator for seeing how long a given function takes, depending on whether
@@ -300,6 +320,8 @@ def get_pbar(title, maxval):
             if EMBEDDED_MODE: return DummyProgressBar()
         except:
             pass
+    elif "CODENODE" in os.environ:
+        return DummyProgressBar()
     widgets = [ title,
             pb.Percentage(), ' ',
             pb.Bar(marker=pb.RotatingMarker()),
@@ -370,3 +392,9 @@ if "--rpdb" in sys.argv:
     sys.excepthook = rpdb.rpdb_excepthook
     del sys.argv[sys.argv.index("--rpdb")]
 
+#
+# Some exceptions
+#
+
+class NoCUDAException(Exception):
+    pass
