@@ -157,6 +157,7 @@ class RavenPlot(object):
         """
         # This next call fixes some things, but is slower...
         self._redraw_image()
+        self.set_autoscale(False)
         if (zmin in (None,'min')) or (zmax in (None,'max')):    
             imbuff = self._axes.images[-1]._A
             if zmin == 'min':
@@ -167,32 +168,34 @@ class RavenPlot(object):
                 zmax = na.nanmax(imbuff)
                 if dex is not None:
                     zmin = max(zmax/(10**(dex)),na.nanmin(imbuff))
-        if ticks is not None:
-            ticks = na.sort(ticks)
-            self.colorbar.locator = matplotlib.ticker.FixedLocator(ticks)
-            self.colorbar.formatter = matplotlib.ticker.FixedFormatter(["%0.2e" % (x) for x in ticks])
-        elif minmaxtick:
-            if not self.log_field: 
-                ticks = na.array(self.colorbar._ticker()[0],dtype='float')
-                ticks = [zmin] + ticks.tolist() + [zmax]
+        if self.colorbar is not None:
+            if ticks is not None:
+                ticks = na.sort(ticks)
                 self.colorbar.locator = matplotlib.ticker.FixedLocator(ticks)
                 self.colorbar.formatter = matplotlib.ticker.FixedFormatter(["%0.2e" % (x) for x in ticks])
+            elif minmaxtick:
+                if not self.log_field: 
+                    ticks = na.array(self.colorbar._ticker()[0],dtype='float')
+                    ticks = [zmin] + ticks.tolist() + [zmax]
+                    self.colorbar.locator = matplotlib.ticker.FixedLocator(ticks)
+                    self.colorbar.formatter = matplotlib.ticker.FixedFormatter(["%0.2e" % (x) for x in ticks])
+                else:
+                    mylog.error('Sorry, we do not support minmaxtick for linear fields.  It likely comes close by default')
+            elif nticks is not None:
+                if self.log_field:
+                    lin = na.linspace(na.log10(zmin),na.log10(zmax),nticks)
+                    self.colorbar.locator = matplotlib.ticker.FixedLocator(10**lin)
+                    self.colorbar.formatter = matplotlib.ticker.FixedFormatter(["%0.2e" % (10**x) for x in lin])
+                else: 
+                    lin = na.linspace(zmin,zmax,nticks)
+                    self.colorbar.locator = matplotlib.ticker.FixedLocator(lin)
+                    self.colorbar.formatter = matplotlib.ticker.FixedFormatter(["%0.2e" % x for x in lin])
+
             else:
-                mylog.error('Sorry, we do not support minmaxtick for linear fields.  It likely comes close by default')
-        elif nticks is not None:
-            if self.log_field:
-                lin = na.linspace(na.log10(zmin),na.log10(zmax),nticks)
-                self.colorbar.locator = matplotlib.ticker.FixedLocator(10**lin)
-                self.colorbar.formatter = matplotlib.ticker.FixedFormatter(["%0.2e" % (10**x) for x in lin])
-            else: 
-                lin = na.linspace(zmin,zmax,nticks)
-                self.colorbar.locator = matplotlib.ticker.FixedLocator(lin)
-                self.colorbar.formatter = matplotlib.ticker.FixedFormatter(["%0.2e" % x for x in lin])
-        else:
-            if hasattr(self,'_old_locator'):
-                self.colorbar.locator = self._old_locator
-            if hasattr(self,'_old_formatter'):
-                self.colorbar.formatter = self._old_formatter
+                if hasattr(self,'_old_locator'):
+                    self.colorbar.locator = self._old_locator
+                if hasattr(self,'_old_formatter'):
+                    self.colorbar.formatter = self._old_formatter
         self.norm.autoscale(na.array([zmin,zmax]))
         self.image.changed()
         if self.colorbar is not None:
@@ -228,6 +231,9 @@ class RavenPlot(object):
         self._callbacks[id] = lambda a: None
 
     def _run_callbacks(self):
+        self._axes.patches = []
+        self._axes.collections = []
+        self._axes.texts = []
         for cb in self._callbacks:
             cb(self)
 
@@ -278,6 +284,7 @@ class VMPlot(RavenPlot):
                                     top=1.0, left=0.0, right=1.0)
         self.setup_domain_edges(self.data.axis, periodic)
         self.cmap = None
+        self.label_kws = {}
         self.__setup_from_field(field)
         self.__init_temp_image(use_colorbar)
 
@@ -340,7 +347,6 @@ class VMPlot(RavenPlot):
         return buff
 
     def _redraw_image(self, *args):
-        self._axes.clear() # To help out the colorbar
         buff = self._get_buff()
         mylog.debug("Received buffer of min %s and max %s (data: %s %s)",
                     na.nanmin(buff), na.nanmax(buff),
@@ -353,12 +359,17 @@ class VMPlot(RavenPlot):
         else:
             newmin = na.nanmin(buff)
             newmax = na.nanmax(buff)
+        aspect = (self.ylim[1]-self.ylim[0])/(self.xlim[1]-self.xlim[0])
+        if self.image._A.size != buff.size:
+            self._axes.clear()
+            self.image = \
+                self._axes.imshow(buff, interpolation='nearest', norm = self.norm,
+                                aspect=aspect, picker=True, origin='lower')
+        else:
+            self.image.set_data(buff)
+        if self._axes.get_aspect() != aspect: self._axes.set_aspect(aspect)
         if self.do_autoscale:
             self.norm.autoscale(na.array((newmin,newmax)))
-        aspect = (self.ylim[1]-self.ylim[0])/(self.xlim[1]-self.xlim[0])
-        self.image = \
-            self._axes.imshow(buff, interpolation='nearest', norm = self.norm,
-                            aspect=aspect, picker=True, origin='lower')
         self._reset_image_parameters()
         self._run_callbacks()
 
@@ -393,7 +404,7 @@ class VMPlot(RavenPlot):
         self["Unit"] = str(unit)
         self["Width"] = float(width)
         if isinstance(unit, types.StringTypes):
-            unit = self.data.hierarchy[str(unit)]
+            unit = self.data.pf[str(unit)]
         self.width = width / unit
         self._refresh_display_width()
 
@@ -443,7 +454,7 @@ class VMPlot(RavenPlot):
             data_label = self.pf.field_info[field_name].get_label(proj)
         else: data_label = self.datalabel
         if self.colorbar != None:
-            self.colorbar.set_label(str(data_label))
+            self.colorbar.set_label(str(data_label), **self.label_kws)
 
 class FixedResolutionPlot(VMPlot):
 
@@ -577,14 +588,15 @@ class ParticlePlot(RavenPlot):
     _type_name = "ParticlePlot"
     def __init__(self, data, axis, width, p_size=1.0, col='k', stride=1.0,
                  figure = None, axes = None):
-        RavenPlot.__init__(self, data, [], figure, axes)
+        kwargs = {}
+        if figure is None: kwargs['size'] = (8,8)
+        RavenPlot.__init__(self, data, [], figure, axes, **kwargs)
         self._figure.subplots_adjust(hspace=0, wspace=0, bottom=0.0,
                                     top=1.0, left=0.0, right=1.0)
         self.axis = axis
         self.setup_domain_edges(axis)
         self.axis_names['Z'] = col
-        from Callbacks import ParticleCallback
-        self.add_callback(ParticleCallback(axis, width, p_size, col, stride))
+        self.modify["particles"](width, p_size, col, stride)
         self.set_width(1,'unitary')
 
     def _redraw_image(self, *args):
@@ -592,12 +604,6 @@ class ParticlePlot(RavenPlot):
         self._reset_image_parameters()
         self._run_callbacks()
 
-    def set_xlim(self, xmin, xmax):
-        self.xlim = (xmin,xmax)
-
-    def set_ylim(self, ymin, ymax):
-        self.ylim = (ymin,ymax)
-
     def _generate_prefix(self, prefix):
         self.prefix = "_".join([prefix, self._type_name, \
             lagos.axis_names[self.axis], self.axis_names['Z']])
@@ -609,7 +615,7 @@ class ParticlePlot(RavenPlot):
         self["Unit"] = str(unit)
         self["Width"] = float(width)
         if isinstance(unit, types.StringTypes):
-            unit = self.data.hierarchy[str(unit)]
+            unit = self.data.pf[str(unit)]
         self.width = width / unit
         self._refresh_display_width()
 
@@ -636,6 +642,9 @@ class ParticlePlot(RavenPlot):
         self._axes.set_yticks(())
         self._axes.set_ylabel("")
         self._axes.set_xlabel("")
+        l, b, width, height = _get_bounds(self._axes.bbox)
+        self._axes.set_xlim(0, width)
+        self._axes.set_ylim(0, height)
 
 class ProfilePlot(RavenPlot):
     _x_label = None
@@ -744,7 +753,7 @@ class PhasePlot(ProfilePlot):
         self.image = None
         self.set_cmap(cmap)
         self._zlim = None
-
+     
         self.axis_names["X"] = fields[0]
         self.axis_names["Y"] = fields[1]
         self.axis_names["Z"] = fields[2]
@@ -756,6 +765,14 @@ class PhasePlot(ProfilePlot):
         self._log_z = self.setup_bins(self.fields[2])
         self.__init_colorbar()
 
+    def _run_callbacks(self):
+        # We sublcass to avoid the problem of replacing self.image,
+        # which is a collection
+        self._axes.patches = []
+        self._axes.texts = []
+        for cb in self._callbacks:
+            cb(self)
+
     def __init_colorbar(self):
         temparray = na.ones((self.x_bins.size, self.y_bins.size))
         self.norm = matplotlib.colors.Normalize()
@@ -771,10 +788,10 @@ class PhasePlot(ProfilePlot):
         if self.image != None and self.cmap != None:
             self.image.set_cmap(self.cmap)
 
-    def switch_z(self, field, weight="CellMassMsun", accumulation=False):
+    def switch_z(self, field, weight="CellMassMsun", accumulation=False, fractional=False):
         self.fields[2] = field
         self.axis_names["Z"] = field
-        if field not in self.data.keys(): self.data.add_fields(field, weight, accumulation)
+        if field not in self.data.keys(): self.data.add_fields(field, weight, accumulation, fractional=fractional)
         self._log_z = self.setup_bins(self.fields[2])
 
     def set_xlim(self, xmin, xmax):
