@@ -5,7 +5,7 @@ Author: Matthew Turk <matthewturk@gmail.com>
 Affiliation: KIPAC/SLAC/Stanford
 Homepage: http://yt.enzotools.org/
 License:
-  Copyright (C) 2007-2008 Matthew Turk.  All Rights Reserved.
+  Copyright (C) 2007-2009 Matthew Turk.  All Rights Reserved.
 
   This file is part of yt.
 
@@ -79,7 +79,6 @@ class ReasonMainWindow(wx.Frame):
         self.data_objects = []
         self.locals = {'lagos':lagos,
                        'raven':raven,
-                       'enki':enki,
                        'raven':raven,
                        'outputs':self.outputs,
                        'windows':self.windows,
@@ -156,6 +155,8 @@ class ReasonMainWindow(wx.Frame):
         self.data_tree.Expand(self.data_root)
 
         self.data_tree.Bind(wx.EVT_RIGHT_DOWN, self.OnRightDown)
+        self.data_tree.Bind(wx.EVT_RIGHT_DOWN, self.OnRightDown)
+        self.data_tree.Bind(wx.EVT_LEFT_DCLICK, self.OnRightDown)
         self.Bind(wx.EVT_TREE_ITEM_EXPANDED, self.OnItemExpanded, self.data_tree)
 
         self.__setup_fido_tree()
@@ -275,10 +276,9 @@ class ReasonMainWindow(wx.Frame):
             self.available_fields.Enable(True)
             self.available_fields.SetItems(newItems)
 
-    def add_static_output(self, filename):
-        """
-        Given a filename, add an :class:`EnzoStaticOutput` to the instance.
-        """
+    def _add_static_output(self, filename):
+        # Alright, we choose the hierarchy in the file selector,
+        # so let's strip that extension off
         fn = filename[:-10]
         eso = lagos.EnzoStaticOutput(fn)
         try:
@@ -291,12 +291,7 @@ class ReasonMainWindow(wx.Frame):
         ni = self.data_tree.AppendItem(self.output_root, "%s" % (eso.basename), data=tid)
         self.data_tree.Expand(self.output_root)
 
-    def add_data_object(self, title, object, mids = _SphereObjectMenuItems,
-                        parent_id = None):
-        """
-        Given a *title* for the object, the *object* itself, add a data
-        object to the menu.  User API requires this be a 3D data object.
-        """
+    def _add_data_object(self, title, object, mids, parent_id = None):
         self.data_objects.append(object)
         tid = wx.TreeItemData((object, title, len(self.data_objects), mids))
         if parent_id is None: parent_id = self.data_root
@@ -305,7 +300,7 @@ class ReasonMainWindow(wx.Frame):
 
     def _add_sphere(self, title, sphere, parent_id=None):
         # These all get passed in
-        self.add_data_object(title, sphere, _SphereObjectMenuItems, parent_id)
+        self._add_data_object(title, sphere, _SphereObjectMenuItems, parent_id)
 
     def __add_profile_wrapper(self, obj):
         """
@@ -329,7 +324,7 @@ class ReasonMainWindow(wx.Frame):
     def _add_profile(self, event=None, data_object = None):
         MyID = wx.NewId()
         parent_id = None
-        if data_object is None: parent_id, data_object = self._get_output()
+        if data_object is None: parent_id, data_object = self.get_output()
         p1ds = Profile1DSetup(data_object, self)
         if not p1ds.ShowModal() == wx.ID_OK:
             p1ds.Destroy()
@@ -352,7 +347,7 @@ class ReasonMainWindow(wx.Frame):
                             mw = self, parent_id=parent_id),
             "Profile Plot %s" % MyID, MyID)
         if parent_id is not None:
-            self.add_data_object("Profile: %s" % (argdict['bin_field']),
+            self._add_data_object("Profile: %s" % (argdict['bin_field']),
                                self.windows[-1].plot.data,
                                _ProfileObjectMenuItems, parent_id)
 
@@ -360,7 +355,7 @@ class ReasonMainWindow(wx.Frame):
     def _add_phase(self, event=None, data_object = None):
         MyID = wx.NewId()
         parent_id = None
-        if data_object is None: parent_id, data_object = self._get_output()
+        if data_object is None: parent_id, data_object = self.get_output()
         p2ds = Profile2DSetup(data_object, self)
         if not p2ds.ShowModal() == wx.ID_OK:
             p2ds.Destroy()
@@ -384,7 +379,7 @@ class ReasonMainWindow(wx.Frame):
                           mw = self, parent_id=parent_id),
             "Phase Plot %s" % MyID, MyID)
         if parent_id is not None:
-            self.add_data_object("Phase: %s, %s" % (argdict['x_bin_field'],
+            self._add_data_object("Phase: %s, %s" % (argdict['x_bin_field'],
                                                  argdict['y_bin_field']),
                                self.windows[-1].plot.data,
                                _ProfileObjectMenuItems, parent_id)
@@ -397,7 +392,7 @@ class ReasonMainWindow(wx.Frame):
 
     def _add_proj(self, event=None):
         MyID = wx.NewId()
-        parent_id, data_object = self._get_output()
+        parent_id, data_object = self.get_output()
         width = 1.0
         unit = "1"
         proj_setup = ProjectionSetup(data_object, self)
@@ -422,7 +417,7 @@ class ReasonMainWindow(wx.Frame):
                               parent_id=parent_id),
                 "%s - Projection - %s" % (data_object.basename, ax),
                 MyID)
-            self.add_data_object("Proj: %s - %s (%s)" % (ax, field, weight_field),
+            self._add_data_object("Proj: %s - %s (%s)" % (ax, field, weight_field),
                                self.windows[-1].plot.data,
                                _ProjObjectMenuItems, parent_id)
             print "Adding with ID:", MyID
@@ -432,7 +427,7 @@ class ReasonMainWindow(wx.Frame):
 
     def _add_slice(self, event=None):
         MyID = wx.NewId()
-        parent_id, data_object = self._get_output()
+        parent_id, data_object = self.get_output()
         field, width, unit = "Density", 1.0, '1'
         for i, ax in enumerate('xyz'):
             mylog.info("Adding %s slice of %s" % (ax, data_object))
@@ -446,13 +441,13 @@ class ReasonMainWindow(wx.Frame):
                               parent_id = parent_id),
                 "%s - Slice - %s" % (data_object.basename, ax),
                 MyID)
-            self.add_data_object("Slice: %s" % (ax),
+            self._add_data_object("Slice: %s" % (ax),
                                self.windows[-1].plot.data,
                                _SliceObjectMenuItems, parent_id)
         for w in self.windows[-3:]: w.ChangeWidth(1,'1')
 
     def _export_data_object(self, event):
-        parent_id, data_object = self._get_output()
+        parent_id, data_object = self.get_output()
         # Get a file name and then attempt to export.
         dlg = wx.FileDialog( \
             self, message="Save Data As ...", defaultDir=os.getcwd(), \
@@ -473,7 +468,7 @@ class ReasonMainWindow(wx.Frame):
     def _extract_set(self, event=None, data_object=None):
         MyID = wx.NewId()
         parent_id = None
-        if data_object is None: parent_id, data_object = self._get_output()
+        if data_object is None: parent_id, data_object = self.get_output()
         ess = ExtractSetSetup(data_object, self)
         if not ess.ShowModal() == wx.ID_OK:
             ess.Destroy()
@@ -481,23 +476,18 @@ class ReasonMainWindow(wx.Frame):
         ind = ess.return_indices()
         ess.Destroy()
         extracted_set = data_object.extract_region(ind)
-        self.add_data_object("Extracted Set",
+        self._add_data_object("Extracted Set",
                               extracted_set,
                               _SphereObjectMenuItems, parent_id)
 
-    def add_cutting_wrapper(self, parameter_file, normal, center):
-        """
-        Given a *parameter_file*, a *normal* vector and a *center*, create
-        and add an :class:`EnzoCuttingPlane` object.
-        """
-        self._add_cutting(parameter_file=parameter_file, normal=normal,
-                         center=center)
+    def __add_cutting_wrapper(self, parameter_file, normal):
+        self._add_cutting(parameter_file=parameter_file, normal=normal)
 
     def _add_cutting(self, event=None, parameter_file = None, normal=None,
                      center = None):
         parent_id = None
         if parameter_file is None or normal is None or center is None:
-            parent_id, data_object = self._get_output()
+            parent_id, data_object = self.get_output()
             data_object.set_field_parameter("bulk_velocity",
                 data_object.quantities["BulkVelocity"](lazy_reader=True))
             normal = data_object.quantities["AngularMomentumVector"](lazy_reader=True)
@@ -514,15 +504,13 @@ class ReasonMainWindow(wx.Frame):
                             CreationID=MyID, axis=4, normal=normal,
                             center = center, parent_id=parent_id),
             "%s - Cutting Plane" % (parameter_file.basename), MyID)
-        self.add_data_object("Cutting Plane" % (parameter_file),
+        self._add_data_object("Cutting Plane" % (parameter_file),
                               self.windows[-1].plot.data,
                               _CuttingPlaneObjectMenuItems, parent_id)
         self.windows[-1].ChangeWidth(1,'1')
 
-    def _get_output(self, event=None):
-        """
-        Determine and return the selected outputs.
-        """
+    def get_output(self, event=None):
+        # Figure out which outputs are selected
         #tid = self.data_tree.GetFirstSelected()
         tid = self.data_tree.GetSelection()
         ii = self.data_tree.GetItemData(tid).GetData()[0]
@@ -574,7 +562,7 @@ class ReasonMainWindow(wx.Frame):
                                "", wildcard, wx.OPEN)
         if dialog.ShowModal() == wx.ID_OK:
             file = dialog.GetPath()
-            self.add_static_output(file)
+            self._add_static_output(file)
         dialog.Destroy()
 
     def OnOpenEditor(self, event):
