@@ -9,6 +9,10 @@ def configuration(parent_package='', top_path=None):
     config.add_subpackage('fido')
     config.add_subpackage('reason')
     config.add_subpackage('extensions')
+    config.add_extension("amr_utils", 
+        ["yt/amr_utils.c", "yt/_amr_utils/FixedInterpolator.c"], 
+        include_dirs=["yt/_amr_utils/"],
+        libraries=["m"])
     config.make_config_py()
     config.make_svn_version_py()
     return config
